<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ublss="http://www.CraneSoftwrights.com/ns/ublss" version="1.0">

  <!--hscodes.xsl $Revision: 1.4 $ $Date: 2003/01/11 20:26:33 $-->

  <!--Provide a table of transformations for Harmonised System Nature Codes-->

  
   <xsl:variable name="hscode-error"/><!--set non-empty to signal error-->

  <!--Return the short string associated with the code-->
  
   <xsl:template name="hscode-short">
      <xsl:param name="code" select="."/>
      <xsl:call-template name="ublss:hscode">
         <xsl:with-param name="code" select="$code"/>
      </xsl:call-template>
   </xsl:template>

  <!--Return the long string associated with the code-->
  
   <xsl:template name="hscode-long">
      <xsl:param name="code" select="."/>
      <xsl:call-template name="ublss:hscode">
         <xsl:with-param name="code" select="$code"/>
         <xsl:with-param name="do-long" select="'yes'"/>
      </xsl:call-template>
   </xsl:template>

  <!--Return the desired string associated with the code-->
  
   <xsl:template name="ublss:hscode">
      <xsl:param name="code" select="."/>
      <xsl:param name="do-long"/>
      <xsl:variable name="codenode" select="document('')/*/ublss:hscodes/hscode[ @code=$code ]"/>
      <xsl:choose>
         <xsl:when test="$codenode">
            <xsl:choose>
               <xsl:when test="$do-long">
                  <xsl:value-of select="$codenode/long"/>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:value-of select="$codenode/short"/>
               </xsl:otherwise>
            </xsl:choose>
         </xsl:when>
         <xsl:when test="not( string( $code ) )">
            <xsl:text>Code: unspecified</xsl:text>
         </xsl:when>
         <xsl:when test="not( $hscode-error )">
            <xsl:text/>Code: <xsl:value-of select="$code"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:message terminate="yes">
               <xsl:text>Unrecognized Harmonised System Nature Code: </xsl:text>
               <xsl:value-of select="$code"/>
            </xsl:message>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

  
   <ublss:hscodes>
      <hscode code="01">
         <long>LIVE ANIMALS</long>
         <short>LIVE ANIMALS</short>
      </hscode>
      <hscode code="02">
         <long>MEAT AND EDIBLE MEAT OFFAL</long>
         <short>MEAT</short>
      </hscode>
      <hscode code="03">
         <long>FISH AND CRUSTACEANS, MOLLUSCS AND OTHER AQUATIC INVERTEBRATES</long>
         <short>FISH AND CRUSTACEANS</short>
      </hscode>
      <hscode code="04">
         <long>DAIRY PRODUCE; BIRDS' EGGS; NATURAL HONEY; EDIBLE PRODUCTS OF ANIMAL ORIGIN, NOT ELSEWHERE SPECIFIED OR INCLUDED</long>
         <short>DAIRY PRODUCE</short>
      </hscode>
      <hscode code="05">
         <long>PRODUCTS OF ANIMAL ORIGIN, NOT ELSEWHERE SPECIFIED OR INCLUDED</long>
         <short>OTHER ANIMAL PRODUCTS</short>
      </hscode>
      <hscode code="06">
         <long>LIVE TREES AND OTHER PLANTS; BULBS, ROOTS AND THE LIKE; CUT FLOWERS AND ORNAMENTAL FOLIAGE</long>
         <short>LIVE TREES AND PLANTS</short>
      </hscode>
      <hscode code="07">
         <long>EDIBLE VEGETABLES AND CERTAIN ROOTS AND TUBERS</long>
         <short>EDIBLE VEGETABLES</short>
      </hscode>
      <hscode code="08">
         <long>EDIBLE FRUIT AND NUTS; PEEL OF CITRUS FRUIT OR MELONS</long>
         <short>EDIBLE FRUIT AND NUTS</short>
      </hscode>
      <hscode code="09">
         <long>COFFEE, TEA, MATE AND SPICES</long>
         <short>COFFEE, TEA AND SPICES</short>
      </hscode>
      <hscode code="10">
         <long>CEREALS</long>
         <short>CEREALS</short>
      </hscode>
      <hscode code="11">
         <long>PRODUCTS OF THE MILLING INDUSTRY; MALT; STARCHES; INULIN; WHEAT GLUTEN</long>
         <short>PRODUCTS OF MILLING</short>
      </hscode>
      <hscode code="12">
         <long>OIL SEEDS AND OLEAGINOUS FRUITS; MISCELLANEOUS GRAINS, SEEDS AND FRUIT; INDUSTRIAL OR MEDICINAL PLANTS; STRAW AND FODDER</long>
         <short>OIL SEEDS AND OLEAGINOUS FRUITS</short>
      </hscode>
      <hscode code="13">
         <long>LAC; GUMS, RESINS, AND OTHER VEGETABLE SAPS AND EXTRACTS</long>
         <short>GUMS, RESINS, AND VEGETABLE SAPS</short>
      </hscode>
      <hscode code="14">
         <long>VEGETABLE PLAITING MATERIALS; VEGETABLE PRODUCTS NOT ELSEWHERE SPECIFIED OR INCLUDED</long>
         <short>OTHER VEGETABLE PRODUCTS</short>
      </hscode>
      <hscode code="15">
         <long>ANIMAL AND VEGETABLE FATS AND OILS AND THEIR CLEAVAGE PRODUCTS; PREPARED EDIBLE FATS; ANIMAL OR VEGETABLE WAXES</long>
         <short>ANIMAL AND VEGETABLE FATS</short>
      </hscode>
      <hscode code="16">
         <long>PREPARATIONS OF MEAT, OF FISH OR OF CRUSTACEANS, MOLLUSCS OR OTHER AQUATIC INVERTEBRATES</long>
         <short>PREPARATIONS OF MEAT, FISH OR CRUST</short>
      </hscode>
      <hscode code="17">
         <long>SUGARS AND SUGAR CONFECTIONERY</long>
         <short>SUGARS AND SUGAR CONFECTIONERY</short>
      </hscode>
      <hscode code="18">
         <long>COCOA AND COCOA CONFECTIONERY</long>
         <short>COCOA AND COCOA CONFECTIONERY</short>
      </hscode>
      <hscode code="19">
         <long>PREPARATIONS OF CEREALS, FLOUR, STARCH OR MILK; PASTRYCOOKS' PRODUCTS</long>
         <short>PREPARATIONS OF CEREALS OR MILK</short>
      </hscode>
      <hscode code="20">
         <long>PREPARATIONS OF VEGETABLES, FRUIT, NUTS OR OTHER PARTS OF PLANTS</long>
         <short>PREPARATIONS OF VEGETABLES</short>
      </hscode>
      <hscode code="21">
         <long>MISCELLANEOUS EDIBLE PREPARATIONS</long>
         <short>MISCELLANEOUS EDIBLE PREPARATIONS</short>
      </hscode>
      <hscode code="22">
         <long>BEVERAGES, SPIRITS AND VINEGAR</long>
         <short>BEVERAGES, SPIRITS AND VINEGAR</short>
      </hscode>
      <hscode code="23">
         <long>RESIDUES AND WASTE FROM THE FOOD INDUSTRIES; PREPARED ANIMAL FODDER</long>
         <short>RESIDUES FROM FOOD INDUSTRIES</short>
      </hscode>
      <hscode code="24">
         <long>TOBACCO AND MANUFACTURED TOBACCO SUBSTITUTES</long>
         <short>TOBACCO AND SUBSTITUTES</short>
      </hscode>
      <hscode code="25">
         <long>SALT; SULPHUR; EARTHS AND STONE; PLASTERING MATERIALS, LIME OR CEMENT</long>
         <short>SALT; SULPHUR; STONE; CEMENT</short>
      </hscode>
      <hscode code="26">
         <long>ORES, SLAG AND ASH</long>
         <short>ORES, SLAG AND ASH</short>
      </hscode>
      <hscode code="27">
         <long>MINERAL FUELS, MINERAL OILS AND PRODUCTS OF THEIR DISTILLATION; BITUMINOUS SUBSTANCES; MINERAL WAXES</long>
         <short>MINERAL FUELS</short>
      </hscode>
      <hscode code="28">
         <long>INORGANIC CHEMICALS; INORGANIC OR ORGANIC COMPOUNDS OF PRECIOUS METALS,; OF RARE EARTH METALS, OF RADIOACTIVE ELEMENTS OR OF ISOTOPES</long>
         <short>INORGANIC CHEMICALS</short>
      </hscode>
      <hscode code="29">
         <long>ORGANIC CHEMICALS</long>
         <short>ORGANIC CHEMICALS</short>
      </hscode>
      <hscode code="30">
         <long>PHARMACEUTICAL PRODUCTS</long>
         <short>PHARMACEUTICAL PRODUCTS</short>
      </hscode>
      <hscode code="31">
         <long>FERTILISERS</long>
         <short>FERTILISERS</short>
      </hscode>
      <hscode code="32">
         <long>TANNING OR DYEING EXTRACTS; TANNINS AND THEIR DERIVATIVES; DYES, PIGMENTS AND OTHER COLOURING MATTER; PAINTS AND VARNISHES; PUTTY AND OTHER MASTICS; INKS</long>
         <short>TANNING OR DYEING EXTRACTS</short>
      </hscode>
      <hscode code="33">
         <long>ESSENTIAL OILS AND RESINOIDS; PERFUMERY, COSMETIC OR TOILET PREPARATIONS</long>
         <short>ESSENTIAL OILS AND RESINOIDS</short>
      </hscode>
      <hscode code="34">
         <long>SOAP; ORGANIC SURFACE-ACTIVE AGENTS, WASHING PREPARATIONS LUBRICATING PREPARATIONS, ARTIFICIAL WAXES, PREPARED WAXES, POLISHING OR SCOURING PREPARATIONS, CANDLES, MODELLING PASTES, DENTAL PREPARATIONS WITH A BASIS OF PLASTER</long>
         <short>SOAP; WAXES, CANDLES</short>
      </hscode>
      <hscode code="35">
         <long>ALBUMINOIDAL SUBSTANCES; MODIFIED STARCHES; GLUES; ENZYMES</long>
         <short>ALBUMINOIDAL SUBSTANCES</short>
      </hscode>
      <hscode code="36">
         <long>EXPLOSIVES; PYROTECHNIC PRODUCTS; MATCHES; PYROPHORIC ALLOYS; CERTAIN COMBUSTIBLE PREPARATIONS</long>
         <short>EXPLOSIVES</short>
      </hscode>
      <hscode code="37">
         <long>PHOTOGRAPHIC OR CINEMATOGRAPHIC GOODS</long>
         <short>PHOTOGRAPHIC GOODS</short>
      </hscode>
      <hscode code="38">
         <long>MISCELLANEOUS CHEMICAL PRODUCTS</long>
         <short>MISCELLANEOUS CHEMICAL PRODUCTS</short>
      </hscode>
      <hscode code="39">
         <long>PLASTICS AND ARTICLES THEREOF</long>
         <short>PLASTICS AND ARTICLES THEREOF</short>
      </hscode>
      <hscode code="40">
         <long>RUBBER AND ARTICLES THEREOF</long>
         <short>RUBBER AND ARTICLES THEREOF</short>
      </hscode>
      <hscode code="41">
         <long>RAW HIDES AND SKINS (OTHER THAN FURSKINS) AND LEATHER</long>
         <short>RAW HIDES</short>
      </hscode>
      <hscode code="42">
         <long>ARTICLES OF LEATHER; SADDLERY AND HARNESS; TRAVEL GOODS, HANDBAGS AND SIMILAR CONTAINERS; ARTICLES OF ANIMAL GUT (OTHER THAN SILK-WORM GUT)</long>
         <short>ARTICLES OF LEATHER</short>
      </hscode>
      <hscode code="43">
         <long>FURSKINS AND ARTIFICIAL FUR; MANUFACTURES THEREOF</long>
         <short>FURSKINS AND ARTIFICIAL FUR</short>
      </hscode>
      <hscode code="44">
         <long>WOOD AND ARTICLES OF WOOD; WOOD CHARCOAL</long>
         <short>WOOD AND ARTICLES OF WOOD</short>
      </hscode>
      <hscode code="45">
         <long>CORK AND ARTICLES OF CORK</long>
         <short>CORK</short>
      </hscode>
      <hscode code="46">
         <long>MANUFACTURES OF STRAW, ESPARTO OR OF OTHER PLAITING MATERIALS; BASKETWARE AND WICKERWORK</long>
         <short>MANUFACTURES OF STRAW</short>
      </hscode>
      <hscode code="47">
         <long>PULP OF WOOD OR OF OTHER FIBROUS CELLULOSIC MATERIAL; WASTE AND SCRAP OF PAPER OR PAPERBOARD</long>
         <short>PULP OF WOOD</short>
      </hscode>
      <hscode code="48">
         <long>PAPER AND PAPERBOARD; ARTICLES OF PAPER PULP, OF PAPER OR OF PAPERBOARD</long>
         <short>PAPER AND PAPERBOARD</short>
      </hscode>
      <hscode code="49">
         <long>PRINTED BOOKS, NEWSPAPERS, PICTURE AND OTHER ARTICLES OF THE PRINTING INDUSTRY; MANUSCRIPTS, TYPESCRIPTS AND PLANS</long>
         <short>PRINTED BOOKS, NEWSPAPERS</short>
      </hscode>
      <hscode code="50">
         <long>SILK</long>
         <short>SILK</short>
      </hscode>
      <hscode code="51">
         <long>WOOL, FINE OR COARSE ANIMAL HAIR; HORSEHAIR YARN AND WOVEN FABRIC</long>
         <short>WOOL</short>
      </hscode>
      <hscode code="52">
         <long>COTTON</long>
         <short>COTTON</short>
      </hscode>
      <hscode code="53">
         <long>VEGETABLE TEXTILE FIBRES (OTHER THAN COTTON); PAPER YARN AND WOVEN FABRICS OF PAPER YARN</long>
         <short>OTHER VEGETABLE TEXTILE FIBRES</short>
      </hscode>
      <hscode code="54">
         <long>MAN-MADE FILAMENTS</long>
         <short>MAN-MADE FILAMENTS</short>
      </hscode>
      <hscode code="55">
         <long>MAN-MADE STAPLE FIBRES</long>
         <short>MAN-MADE STAPLE FIBRES</short>
      </hscode>
      <hscode code="56">
         <long>WADDING, FELT AND NONWOVENS; SPECIAL YARNS; TWINE, CORDAGE, ROPES AND CABLES AND ARTICLES THEREOF</long>
         <short>WADDING, FELT AND NONWOVENS</short>
      </hscode>
      <hscode code="57">
         <long>CARPETS AND OTHER TEXTILE FLOOR COVERINGS</long>
         <short>CARPETS</short>
      </hscode>
      <hscode code="58">
         <long>SPECIAL WOVEN FABRICS; TUFTED TEXTILE FABRICS; LACE; TAPESTRIES; TRIMMINGS; EMBROIDERY</long>
         <short>SPECIAL WOVEN FABRICS</short>
      </hscode>
      <hscode code="59">
         <long>IMPREGNATED, COATED, COVERED OR LAMINATED TEXTILE FABRICS; TEXTILE ARTICLES OF A KIND SUITABLE FOR INDUSTRIAL USE</long>
         <short>IMPREGNATED TEXTILE FABRICS</short>
      </hscode>
      <hscode code="60">
         <long>KNITTED OR CROCHETED FABRICS</long>
         <short>KNITTED FABRICS</short>
      </hscode>
      <hscode code="61">
         <long>ARTICLES OF APPAREL AND CLOTHING ACCESSORIES, KNITTED OR CROCHETED</long>
         <short>APPAREL, KNITTED</short>
      </hscode>
      <hscode code="62">
         <long>ARTICLES OF APPAREL AND CLOTHING ACCESSORIES, NOT KNITTED OR CROCHETED</long>
         <short>APPAREL, NOT KNITTED</short>
      </hscode>
      <hscode code="63">
         <long>TEXTILE ARTICLES OTHER THAN CLOTHING OR INDUSTRIAL; WORN CLOTHING AND OTHER WORN TEXTILE ARTICLES; RAGS</long>
         <short>OTHER TEXTILE ARTICLES</short>
      </hscode>
      <hscode code="64">
         <long>FOOTWEAR, GAITERS AND THE LIKE; PARTS OF SUCH ARTICLES</long>
         <short>FOOTWEAR</short>
      </hscode>
      <hscode code="65">
         <long>HEADGEAR AND PARTS THEREOF</long>
         <short>HEADGEAR</short>
      </hscode>
      <hscode code="66">
         <long>UMBRELLAS, SUN UMBRELLAS, WALKING-STICKS, SEAT-STICKS, WHIPS, RIDING-CROPS AND PARTS THEREOF</long>
         <short>UMBRELLAS,ETC</short>
      </hscode>
      <hscode code="67">
         <long>PREPARED FEATHERS AND DOWN AND ARTICLES THEREOF; ARTIFICIAL FLOWERS; ARTICLES OF HUMAN HAIR</long>
         <short>FEATHERS AND DOWN ARTICLES</short>
      </hscode>
      <hscode code="68">
         <long>ARTICLES OF STONE, PLASTER, CEMENT, ASBESTOS, MICA OR SIMILAR MATERIALS</long>
         <short>ARTICLES OF STONE</short>
      </hscode>
      <hscode code="69">
         <long>CERAMIC PRODUCTS</long>
         <short>CERAMIC PRODUCTS</short>
      </hscode>
      <hscode code="70">
         <long>GLASS AND GLASSWARE</long>
         <short>GLASS AND GLASSWARE</short>
      </hscode>
      <hscode code="71">
         <long>NATURAL OR CULTURED PEARLS, PRECIOUS AND SEMI-PRECIOUS STONES, PRECIOUS METALS, METALS CLAD WITH PRECIOUS METAL AND ARTICLES THEREOF; IMITATION JEWELLERY; COIN</long>
         <short>PEARLS</short>
      </hscode>
      <hscode code="72">
         <long>IRON AND STEEL</long>
         <short>IRON AND STEEL</short>
      </hscode>
      <hscode code="73">
         <long>ARTICLES OF IRON OR STEEL</long>
         <short>ARTICLES OF IRON OR STEEL</short>
      </hscode>
      <hscode code="74">
         <long>COPPER AND ARTICLES THEREOF</long>
         <short>COPPER AND ARTICLES THEREOF</short>
      </hscode>
      <hscode code="75">
         <long>NICKEL AND ARTICLES THEREOF</long>
         <short>NICKEL AND ARTICLES THEREOF</short>
      </hscode>
      <hscode code="76">
         <long>ALUMINIUM AND ARTICLES THEREOF</long>
         <short>ALUMINIUM AND ARTICLES THEREOF</short>
      </hscode>
      <hscode code="78">
         <long>LEAD AND ARTICLES THEREOF</long>
         <short>LEAD AND ARTICLES THEREOF</short>
      </hscode>
      <hscode code="79">
         <long>ZINC AND ARTICLES THEREOF</long>
         <short>ZINC AND ARTICLES THEREOF</short>
      </hscode>
      <hscode code="80">
         <long>TIN AND ARTICLES THEREOF</long>
         <short>TIN AND ARTICLES THEREOF</short>
      </hscode>
      <hscode code="81">
         <long>METALS (OTHER THAN IRON, STEEL, COPPER, NICKEL, ALUMINIUM, LEAD, ZINC, TIN OR PRECIOUS METALS) AND ARTICLES THEREOF; CERMETS AND ARTICLES THEREOF</long>
         <short>OTHER METALS</short>
      </hscode>
      <hscode code="82">
         <long>TOOLS, IMPLEMENTS, CUTLERY, SPOONS AND FORKS, OF BASE METAL; PARTS THEREOF OF BASE METAL</long>
         <short>METAL TOOLS</short>
      </hscode>
      <hscode code="83">
         <long>BASE METAL ARTICLES OTHER THAN TOOLS, IMPLEMENTS OR CUTLERY</long>
         <short>OTHER METAL ARTICLES</short>
      </hscode>
      <hscode code="84">
         <long>NUCLEAR REACTORS, BOILERS, MACHINERY AND MECHANICAL APPLIANCES; PARTS THEREOF</long>
         <short>NUCLEAR REACTORS AND PARTS</short>
      </hscode>
      <hscode code="85">
         <long>ELECTRICAL MACHINERY AND EQUIPMENT AND PARTS THEREOF; SOUND RECORDERS AND REPRODUCERS, TELEVISION IMAGE AND SOUND RECORDERS AND REPRODUCERS, AND PARTS AND ACCESSORIES OF SUCH ARTICLES</long>
         <short>ELECTRICAL EQUIPMENT AND PARTS</short>
      </hscode>
      <hscode code="86">
         <long>RAILWAY OR TRAMWAY LOCOMOTIVES, ROLLING STOCK AND PARTS THEREOF; RAILWAY OR TRAMWAY TRACK FIXTURES AND FITTINGS AND PARTS THEREOF; MECHANICAL (INCLUDING ELECTRO-MECHANICAL) TRAFFIC SIGNALLING EQUIPMENT OF ALL KINDS</long>
         <short>RAILWAY ROLLING STOCK</short>
      </hscode>
      <hscode code="87">
         <long>VEHICLES OTHER THAN RAILWAY OR TRAMWAY ROLLING-STOCK, AND PARTS AND ACCESSORIES THEREOF</long>
         <short>OTHER VEHICLES</short>
      </hscode>
      <hscode code="88">
         <long>AIRCRAFT, SPACECRAFT, AND PARTS THEREOF</long>
         <short>AIRCRAFT AND PARTS</short>
      </hscode>
      <hscode code="89">
         <long>SHIPS, BOATS AND FLOATING STRUCTURES</long>
         <short>SHIPS AND BOATS</short>
      </hscode>
      <hscode code="90">
         <long>OPTICAL, PHOTOGRAPHIC, CINEMATOGRAPHIC, MEASURING, CHECKING, PRECISION, MEDICAL OR SURGICAL INSTRUMENTS AND APPARATUS; PARTS AND ACCESSORIES THEREOF</long>
         <short>OPTICAL AND MEDICAL INSTRUMENTS</short>
      </hscode>
      <hscode code="91">
         <long>CLOCKS AND WATCHES AND PARTS THEREOF</long>
         <short>CLOCKS AND WATCHES AND PARTS</short>
      </hscode>
      <hscode code="92">
         <long>MUSICAL INSTRUMENTS; PARTS AND ACCESSORIES THEREOF</long>
         <short>MUSICAL INSTRUMENTS AND PARTS</short>
      </hscode>
      <hscode code="93">
         <long>ARMS AND AMMUNITION; PARTS AND ACCESSORIES THEREOF</long>
         <short>ARMS AND AMMUNITION AND PARTS</short>
      </hscode>
      <hscode code="94">
         <long>FURNITURE; BEDDING, CUSHIONS AND SIMILAR STUFFED FURNISHINGS; LAMPS AND LIGHTING FITTINGS, NOT ELSEWHERE SPECIFIED OR INCLUDED; ILLUMINATED SIGNS, ILLUMINATED NAME-PLATES AND THE LIKE; PREFABRICATED BUILDINGS</long>
         <short>OTHER FURNITURE</short>
      </hscode>
      <hscode code="95">
         <long>TOYS, GAMES AND SPORTS REQUISITES; PARTS AND ACCESSORIES THEREOF</long>
         <short>GAMES AND SPORTS REQUISITES</short>
      </hscode>
      <hscode code="96">
         <long>MANUFACTURED ARTICLES OF VEGETABLE AND ANIMAL PRODUCTS NOT ELSEWHERE SPECIFIED; BROOMS AND BRUSHES; BUTTONS; PENS AND PENCILS; TYPEWRITER RIBBONS; CIGARETTE LIGHTERS; SMOKING PIPES; COMBS, HAIRPINS AND CURLERS; TAILORS' DUMMIES</long>
         <short>OTHER VEGETABLE OR ANIMAL PRODUCTS</short>
      </hscode>
      <hscode code="97">
         <long>WORKS OF ART, COLLECTORS' PIECES AND ANTIQUES</long>
         <short>WORKS OF ART AND ANTIQUES</short>
      </hscode>
      <hscode code="98">
         <long>SPECIAL TRANSACTIONS NOT CLASSIFIED ACCORDING TO KIND</long>
         <short>SPECIAL TRANSACTIONS</short>
      </hscode>
      <hscode code="99">
         <long>COMBINED CONFIDENTIAL ITEMS AND MISCELLANEOUS ITEMS</long>
         <short>CONFIDENTIAL OR MISCELLANEOUS</short>
      </hscode>
   </ublss:hscodes>


</xsl:stylesheet>